@@ -511,7 +511,10 @@ class Trace3d(MagicProperties):
     @updatefunc.setter
     def updatefunc(self, val):
         if val is None:
-            val = lambda: {}
+
+            def val():
+                return {}
+
         msg = ""
         valid_props = list(self._property_names_generator())
         if not callable(val):
