@@ -412,10 +412,6 @@ def test_collection_describe():
         "Collection",
         "│   • position: [0. 0. 0.] mm",
         "│   • orientation: [0. 0. 0.] degrees",
-        "│   • children_all: [Cuboid(id=REGEX, label='x'), Cuboid(id=REGEX, label='y')]",
-        "│   • collections_all: []",
-        "│   • sensors_all: []",
-        "│   • sources_all: [Cuboid(id=REGEX, label='x'), Cuboid(id=REGEX, label='y')]",
         "├── x",
         "│       • position: [0. 0. 0.] mm",
         "│       • orientation: [0. 0. 0.] degrees",
